Coverage for vcr.serializers.yamlserializer: 78%

# Coverage for vcr.serializers.yamlserializer : 78%

## 9 statements 7 run 2 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | import yaml # Use the libYAML versions if possible try: from yaml import CLoader as Loader, CDumper as Dumper except ImportError: from yaml import Loader, Dumper def deserialize(cassette_string): return yaml.load(cassette_string, Loader=Loader) def serialize(cassette_dict): return yaml.dump(cassette_dict, Dumper=Dumper)